==> SCET-1.6.2-py3-none-any.whl: scet/globales.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from sys import platform
from pathlib import Path
from os.path import join, abspath, dirname, expanduser
from os import makedirs
from datetime import date
from time import strftime
from io import StringIO
from logging import basicConfig, getLogger, StreamHandler, FileHandler,\
    DEBUG, INFO

NOMBRE = 'SCET'
VERSION = "1.6.2"
AUTOR = 'Wolfang A. Torres G.'
TITULO = 'Capibara Detallado'
FECHA = date(2015, 12, 9)
CONTACTO = 'Wolfang.Torres@gmail.com'

FORMATO_FECHA_ISO = "%Y-%m-%d %H:%M:%S"
FORMATO_FECHA = "%d-%m-%Y"
FORMATO_HORA = "%H:%M:%S"
FORMATO_FECHA_HORA = FORMATO_FECHA  + ' ' + FORMATO_HORA

# Crear Logger
LOG_0 = getLogger()
LOG_0.setLevel(DEBUG)
LOG_SCET = getLogger(__name__.split('.')[0])
LOG_SCET.setLevel(DEBUG)

CARPETA_MADRE = abspath(dirname(__file__))
CARPETA_GUIS = join(CARPETA_MADRE, 'InterfacesGraficas')
CARPETA_RECURSOS = join(CARPETA_MADRE, 'Recursos')
CARPETA_BD = join(CARPETA_MADRE, 'BaseDeDatos')
# Escoger una carpeta del usuario para poder escribir
if platform.startswith('win'):
    from win32com.shell import shell
    from win32com.shell.shellcon import CSIDL_LOCAL_APPDATA
    CARPETA_TRABAJO = join(
        shell.SHGetFolderPath(0, CSIDL_LOCAL_APPDATA, None, 0),
        'SCET')
else:
    CARPETA_TRABAJO = expanduser(join('~','.scet'))
# si no existe crearla
if not Path(CARPETA_TRABAJO).exists():
    makedirs(CARPETA_TRABAJO)
LOG_0.debug('Carpeta de trabajo <{}>'.format(CARPETA_TRABAJO))

# Crear loging del sistema
REGISTRO = StringIO('SCET - Registro {}'.format(strftime(FORMATO_FECHA_ISO)))
_rh = StreamHandler(REGISTRO)
_rh.setLevel(DEBUG)
LOG_0.addHandler(_rh)
# configurar logging para SCET
_fh = FileHandler(join(CARPETA_TRABAJO, 'scet.log'), mode='w')
_fh.setLevel(DEBUG)
LOG_SCET.addHandler(_fh)

_ROOT = None
def OBTENER_ROOT():
    global _ROOT
    from tkinter import Tk
    if _ROOT is None:
        _ROOT = Tk()
    return _ROOT

==> SCET-1.6.4-py3-none-any.whl: scet/globales.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from sys import platform
from pathlib import Path
from os.path import join, abspath, dirname, expanduser
from os import makedirs
from datetime import date
from time import strftime
from io import StringIO
from logging import basicConfig, getLogger, StreamHandler, FileHandler,\
    DEBUG, INFO

NOMBRE = 'SCET'
VERSION = "1.6.4"
AUTOR = 'Wolfang A. Torres G.'
TITULO = 'Capibara Detallado'
FECHA = date(2015, 12, 9)
CONTACTO = 'Wolfang.Torres@gmail.com'

FORMATO_FECHA_ISO = "%Y-%m-%d %H:%M:%S"
FORMATO_FECHA = "%d-%m-%Y"
FORMATO_HORA = "%H:%M:%S"
FORMATO_FECHA_HORA = FORMATO_FECHA  + ' ' + FORMATO_HORA

# Crear Logger
LOG_0 = getLogger()
LOG_0.setLevel(DEBUG)
LOG_SCET = getLogger(__name__.split('.')[0])
LOG_SCET.setLevel(DEBUG)

CARPETA_MADRE = abspath(dirname(__file__))
CARPETA_GUIS = join(CARPETA_MADRE, 'InterfacesGraficas')
CARPETA_RECURSOS = join(CARPETA_MADRE, 'Recursos')
CARPETA_BD = join(CARPETA_MADRE, 'BaseDeDatos')
# Escoger una carpeta del usuario para poder escribir
if platform.startswith('win'):
    from ctypes import wintypes, windll, create_unicode_buffer
    CSIDL_APPDATA = 26
    SHGFP_TYPE_CURRENT = 0
    buf = create_unicode_buffer(wintypes.MAX_PATH)
    windll.shell32.SHGetFolderPathW(0, CSIDL_APPDATA, 0, SHGFP_TYPE_CURRENT, buf)
    CARPETA_TRABAJO = join(buf.value, 'SCET')
else:
    CARPETA_TRABAJO = expanduser(join('~','.scet'))
# si no existe crearla
if not Path(CARPETA_TRABAJO).exists():
    makedirs(CARPETA_TRABAJO)
LOG_0.debug('Carpeta de trabajo <{}>'.format(CARPETA_TRABAJO))

# Crear loging del sistema
REGISTRO = StringIO('SCET - Registro {}'.format(strftime(FORMATO_FECHA_ISO)))
_rh = StreamHandler(REGISTRO)
_rh.setLevel(DEBUG)
LOG_0.addHandler(_rh)
# configurar logging para SCET
_fh = FileHandler(join(CARPETA_TRABAJO, 'scet.log'), mode='w')
_fh.setLevel(DEBUG)
LOG_SCET.addHandler(_fh)

_ROOT = None
def OBTENER_ROOT():
    global _ROOT
    from tkinter import Tk
    if _ROOT is None:
        _ROOT = Tk()
    return _ROOT
